==> blanco.plugin.csv_0.7.0-eclipse3.0.zip: src/blanco/plugin/csv/wizards/BlancoCsvWizardPage4.java <==
/*
 * blanco Framework
 * Copyright (C) 2004-2006 IGA Tosiki
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 */
package blanco.plugin.csv.wizards;

import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;

/**
 * vOCEBU[h̃y[W̃NXłB
 * 
 * @author IGA Tosiki
 */
public class BlancoCsvWizardPage4 extends WizardPage {
    public BlancoCsvWizardPage4(ISelection selection) {
        super("wizardPage");
        setTitle("blancoCsvvOCɊ֘AtH_");
    }

    public void createControl(Composite parent) {
        GridLayout gridLayout = new GridLayout();
        gridLayout.numColumns = 1;

        Composite container = new Composite(parent, SWT.NULL);
        container.setLayout(gridLayout);

        new Label(container, SWT.NONE)
                .setText("blancoCsvvOCɊ֘AtH_͉L̂ƂłB");
        new Label(container, SWT.NONE).setText("  1.\[XtH_ (tH_ src 𐄏)");
        new Label(container, SWT.NONE)
                .setText("    \[XtH_ݒ(쐬)邱Ƃ܂B");
        new Label(container, SWT.NONE)
                .setText("  2.^fBNg (tH_ meta/csv ܂)");
        new Label(container, SWT.NONE).setText("    t@C`(CSV)i[܂B");
        new Label(container, SWT.NONE)
                .setText("  3.e|fBNg (tH_ tmp ƂȂ܂)");
        new Label(container, SWT.NONE)
                .setText("  4.\[XR[hfBNg (tH_ blanco/main (Java) blanco.cs/main (C#.NET) ƂȂ܂)");

        setControl(container);
    }
}

==> blanco.plugin.csv_1.0.0-eclipse3.0.zip: src/blanco/plugin/csv/wizards/BlancoCsvWizardPage4.java <==
/*
 * blanco Framework
 * Copyright (C) 2004-2006 IGA Tosiki
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 */
package blanco.plugin.csv.wizards;

import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;

import blanco.csv.BlancoCsvConstants;
import blanco.csv.resourcebundle.BlancoCsvResourceBundle;

/**
 * vOCEBU[h̃y[W̃NXłB
 * 
 * @author IGA Tosiki
 */
public class BlancoCsvWizardPage4 extends WizardPage {
    private static final BlancoCsvResourceBundle fBundle = new BlancoCsvResourceBundle();

    public BlancoCsvWizardPage4(ISelection selection) {
        super("wizardPage");
        setTitle(BlancoCsvConstants.PRODUCT_NAME + "vOCɊ֘AtH_");
    }

    public void createControl(Composite parent) {
        GridLayout gridLayout = new GridLayout();
        gridLayout.numColumns = 1;

        Composite container = new Composite(parent, SWT.NULL);
        container.setLayout(gridLayout);

        new Label(container, SWT.NONE).setText(BlancoCsvConstants.PRODUCT_NAME
                + "vOCɊ֘AtH_͉L̂ƂłB");
        new Label(container, SWT.NONE).setText("  1.\[XtH_ (tH_ src 𐄏)");
        new Label(container, SWT.NONE)
                .setText("    \[XtH_ݒ(쐬)邱Ƃ܂B");
        new Label(container, SWT.NONE).setText("  2.^fBNg (tH_ meta"
                + BlancoCsvConstants.TARGET_SUBDIRECTORY + " ܂)");
        new Label(container, SWT.NONE).setText("    "
                + fBundle.getMetafileDisplayname() + "i[܂B");
        new Label(container, SWT.NONE)
                .setText("  3.e|fBNg (tH_ tmp ƂȂ܂)");
        new Label(container, SWT.NONE)
                .setText("  4.\[XR[hfBNg (tH_ blanco/main (Java) blanco.cs/main (C#.NET) ƂȂ܂)");

        setControl(container);
    }
}
